@@ -2,7 +2,6 @@ import copy
 import os
 import json
 import itertools
-import warnings
 from collections import OrderedDict, defaultdict
 from functools import partial, reduce
 from typing import Optional, Dict, List, Any
@@ -13,7 +12,7 @@ from marshmallow import ValidationError as MarshmallowValidationError
 from paramtools import utils
 from paramtools.schema import ParamToolsSchema
 from paramtools.schema_factory import SchemaFactory
-from paramtools.select import select_eq, select_gt_ix, select_gt
+from paramtools.select import select_eq, select_gt_ix, select_gt, select_lt
 from paramtools.tree import Tree
 from paramtools.typing import ValueObject
 from paramtools.exceptions import (
@@ -28,7 +27,6 @@ from paramtools.exceptions import (
 
 class Parameters:
     defaults = None
-    field_map: Dict = {}
     array_first: bool = False
     label_to_extend: str = None
     uses_extend_func: bool = False
@@ -42,7 +40,7 @@ class Parameters:
         uses_extend_func: bool = False,
         index_rates: Optional[dict] = None,
     ):
-        schemafactory = SchemaFactory(self.defaults, self.field_map)
+        schemafactory = SchemaFactory(self.defaults)
         (
             self._defaults_schema,
             self._validator_schema,
@@ -50,9 +48,12 @@ class Parameters:
             self._data,
         ) = schemafactory.schemas()
         self.label_validators = schemafactory.label_validators
-        self._stateless_label_grid = OrderedDict(
-            [(name, v.grid()) for name, v in self.label_validators.items()]
-        )
+        self._stateless_label_grid = OrderedDict()
+        for name, v in self.label_validators.items():
+            if hasattr(v, "grid"):
+                self._stateless_label_grid[name] = v.grid()
+            else:
+                self._stateless_label_grid[name] = []
         self.label_grid = copy.deepcopy(self._stateless_label_grid)
         self._validator_schema.context["spec"] = self
         self._warnings = {}
@@ -194,17 +195,6 @@ class Parameters:
                         vos, self.label_to_extend, extend_grid
                     ):
                         if self.label_to_extend in vo:
-                            if (
-                                vo[self.label_to_extend]
-                                not in self.label_grid[self.label_to_extend]
-                            ):
-                                msg = (
-                                    f"{param}[{self.label_to_extend}={vo[self.label_to_extend]}] "
-                                    f"is not active in the current state: "
-                                    f"{self.label_to_extend}= "
-                                    f"{self.label_grid[self.label_to_extend]}."
-                                )
-                                warnings.warn(msg)
                             gt = select_gt_ix(
                                 self._data[param]["value"],
                                 True,
@@ -755,6 +745,14 @@ class Parameters:
             tree=self._search_trees.get(param),
         )
 
+    def select_lt(self, param, exact_match, **labels):
+        return select_lt(
+            self._data[param]["value"],
+            exact_match,
+            labels,
+            tree=self._search_trees.get(param),
+        )
+
     def _update_param(self, param, new_values):
         """
         Update the current parameter values with those specified by
