@@ -16,10 +16,10 @@ from paramtools import (
     InconsistentLabelsException,
     collision_list,
     ParameterNameCollisionException,
+    register_custom_type,
+    Parameters,
 )
 
-from paramtools import Parameters
-
 CURRENT_PATH = os.path.abspath(os.path.dirname(__file__))
 
 
@@ -247,17 +247,19 @@ class TestSchema:
             hello = ma.fields.Boolean()
             world = ma.fields.Boolean()
 
+        register_custom_type("custom_type", ma.fields.Nested(Custom()))
+
         class Params(Parameters):
-            field_map = {"custom_type": ma.fields.Nested(Custom)}
             defaults = {
                 "schema": {
-                    "additional_members": {"custom": {"type": "custom_type"}}
+                    "labels": {"custom_label": {"type": "custom_type"}},
+                    "additional_members": {"custom": {"type": "custom_type"}},
                 },
                 "param": {
                     "title": "",
                     "description": "",
                     "type": "int",
-                    "value": 0,
+                    "value": [{"custom_label": {"hello": True}, "value": 0}],
                     "custom": {"hello": True, "world": True},
                 },
             }
@@ -1777,8 +1779,7 @@ class TestExtend:
 
         params = ExtParams()
         params.set_state(d0=list(range(2, 11)))
-        with pytest.warns(UserWarning):
-            params.adjust({"extend_param": [{"d0": 1, "value": -1}]})
+        params.adjust({"extend_param": [{"d0": 1, "value": -1}]})
         assert params.extend_param.tolist() == []
         params.array_first = False
         params.clear_state()
@@ -1905,3 +1906,39 @@ class TestIndex:
                     "indexed_param": [{"d0": 3, "value": 8}],
                 }
             )
+
+
+class TestSelect:
+    def test_select_lt(self):
+        class Params(Parameters):
+            defaults = {
+                "schema": {
+                    "labels": {
+                        "d0": {"type": "int"},
+                        "d1": {
+                            "type": "str",
+                            "validators": {
+                                "choice": {"choices": ["hello", "world"]}
+                            },
+                        },
+                    }
+                },
+                "param": {
+                    "title": "",
+                    "description": "",
+                    "type": "int",
+                    "value": [
+                        {"d0": 1, "d1": "hello", "value": 1},
+                        {"d0": 1, "d1": "world", "value": 1},
+                        {"d0": 2, "d1": "hello", "value": 1},
+                        {"d0": 3, "d1": "world", "value": 1},
+                    ],
+                },
+            }
+
+        params = Params()
+        assert list(params.select_lt("param", False, d0=3)) == [
+            {"d0": 1, "d1": "hello", "value": 1},
+            {"d0": 1, "d1": "world", "value": 1},
+            {"d0": 2, "d1": "hello", "value": 1},
+        ]
