@@ -1,6 +1,6 @@
 import pytest
 
-from paramtools.select import select_eq, select_gt
+from paramtools.select import select_eq, select_gt, select_lt
 
 
 @pytest.fixture
@@ -31,3 +31,11 @@ def test_select_gt(vos):
         {"d0": 2, "d1": "hello", "value": 1},
         {"d0": 3, "d1": "world", "value": 1},
     ]
+
+
+def test_select_lt(vos):
+    assert list(select_lt(vos, True, labels={"d0": 3})) == [
+        {"d0": 1, "d1": "hello", "value": 1},
+        {"d0": 1, "d1": "world", "value": 1},
+        {"d0": 2, "d1": "hello", "value": 1},
+    ]
